Commit: eb16b04b9dac7703042048f676b832894784244e
Author: Sergey Sharybin
Date:   Thu Mar 5 17:20:40 2015 +0500
Branches: master
https://developer.blender.org/rBeb16b04b9dac7703042048f676b832894784244e

CMake: Need to find pugixml.hpp instead of pugixml.h

That's how file is actually called in the upstream.

===================================================================

M       build_files/cmake/Modules/FindPugiXML.cmake

===================================================================

diff --git a/build_files/cmake/Modules/FindPugiXML.cmake 
b/build_files/cmake/Modules/FindPugiXML.cmake
index b1ed45f..f7104c1 100644
--- a/build_files/cmake/Modules/FindPugiXML.cmake
+++ b/build_files/cmake/Modules/FindPugiXML.cmake
@@ -1,7 +1,7 @@
 # - Find PugiXML library
 # Find the native PugiXML includes and library
 # This module defines
 #  PUGIXML_INCLUDE_DIRS, where to find pugixml.h, Set when
 #                        PugiXML is found.
 #  PUGIXML_LIBRARIES, libraries to link against to use PugiiXML.
 #  PUGIXML_ROOT_DIR, The base directory to search for PugiXML.
@@ -38,7 +38,7 @@ SET(_pugixml_SEARCH_DIRS
 
 FIND_PATH(PUGIXML_INCLUDE_DIR
   NAMES
-    pugixml.h
+    pugixml.hpp
   HINTS
     ${_pugixml_SEARCH_DIRS}
   PATH_SUFFIXES
@@ -1,7 +1,7 @@
 # Find the native PugiXML includes and library
 # This module defines
-#  PUGIXML_INCLUDE_DIRS, where to find pugixml.h, Set when
+#  PUGIXML_INCLUDE_DIRS, where to find pugixml.hpp, Set when
 #                        PugiXML is found.
 #  PUGIXML_LIBRARIES, libraries to link against to use PugiiXML.

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
http://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to